package IRStats::View::TopCountriesTable;

use strict;
use warnings;

use IRStats::DatabaseInterface;
use IRStats::Cache;
use IRStats::Visualisation::Graph::DataTable;
use IRStats::View;
use Data::Dumper;

use Locale::Country;

our @ISA = qw/ IRStats::View /;

sub initialise
{
        my ($self) = @_;
	$self->{'sql_params'} = {
		columns => [ 'requester_country', 'COUNT' ],
		group => "requester_country",
		order => {column => "COUNT", direction => "DESC"},
		limit => 11 
	};
	$self->{'visualisation'} = IRStats::Visualisation::Graph::DataTable->new(
	{
		filename => $self->{'params'}->get('id') . ".png",
		title => "Top Countries",
                data_series => [],
		params => $self->{params},
		add_images => 1,
		col_labels => ["Flag", "Country", "Downloads"],
	}
        );
}

sub new
{
        my( $class, $params, $database ) = @_;
        my $self = $class->SUPER::new($params, $database);;
        $self->initialise();
        return $self;
}

sub populate
{
	my ($self) = @_;
##Check Cache
	my $cache = IRStats::Cache->new($self->{'params'});
	if ($cache->exists)
	{
		$self->{'visualisation'} = $cache->read();
		return;
	}

	my $rows = [];
	my $data_series = [];

	my $query = $self->{'database'}->get_stats(
			$self->{'params'},
			$self->{'sql_params'}
			);

	while ( my @row = $query->fetchrow_array() )
	{
		push @{$rows}, \@row ;
	}
	$query->finish(); 

	foreach my $row (@$rows)
	{
		my $country_code = $row->[0];
		my $count = $row->[1];
		my $country_name = code2country($country_code);
		$country_name = 'Unknown' unless $country_name;
		$country_code = 'Unknown' unless $country_code;
		my $flag_url = lc($country_code) . '.png';
		my $flag_img = "<*img=/opt/eprints3/lib/static/irstats/flag_thumbs/png/$flag_url*>";

		#my @data;
		#@data[0] = $count;
		#@data[1] = $flag_img,;
		push @{$data_series}, { citation => $country_name, data => $count, image => $flag_img }; 
	}

	$self->{'visualisation'}->set('data_series',$data_series);

	##write to cache
	$cache->write($self->{'visualisation'});
}

1;
