package IRStats::View::TopTenSearchTermsTable;

use strict;
use warnings;

use IRStats::DatabaseInterface;
use IRStats::Cache;
use IRStats::Visualisation::Graph::DataTable;
use IRStats::View;
use Data::Dumper;


our @ISA = qw/ IRStats::View /;

sub initialise
{
        my ($self) = @_;
	$self->{'sql_params'} = {
		columns => [ 'search_terms', 'COUNT' ],
		group => "search_terms", 
		order => {column => "COUNT", direction =>"DESC"},
		limit => 11
		};
	$self->{'visualisation'} = IRStats::Visualisation::Graph::DataTable->new(
	{
		filename => $self->{'params'}->get('id') . ".png",
		title => "Top Search Terms",
                data_series => [],
		params => $self->{params},
		add_images => 0,
		col_labels => ["Search Term", "Count"],
	}
        );
}

sub new
{
        my( $class, $params, $database ) = @_;
        my $self = $class->SUPER::new($params, $database);;
        $self->initialise();
        return $self;
}

sub populate
{
	my ($self) = @_;
##Check Cache
	my $cache = IRStats::Cache->new($self->{'params'});
	if ($cache->exists)
	{
		$self->{'visualisation'} = $cache->read();
		return;
	}

	my $rows = [];
	my $data_series = [];

	my $query = $self->{'database'}->get_stats(
			$self->{'params'},
			$self->{'sql_params'}
			);

	while ( my @row = $query->fetchrow_array() )
	{
		push @{$rows}, \@row if ($row[0]);
	}
	$query->finish(); 

	foreach my $row (@$rows)
	{
		push @{$data_series}, { citation => $row->[0], data => $row->[1] }; 
	}

	$self->{'visualisation'}->set('data_series',$data_series);

	##write to cache
	$cache->write($self->{'visualisation'});
}


1;
