package IRStats::Visualisation::Graph::DataTable;

use strict;

use IRStats::Visualisation::Graph;
#use perlchartdir;

our @ISA = qw/ IRStats::Visualisation::Graph /;

sub new
{
	my ($class, $data) = @_;
	my $self = $class->SUPER::new($data);

	$self->{add_images} = $data->{add_images};
	$self->{col_labels} = $data->{col_labels};
	return $self;
}

sub quote_javascript
{
	my( $value ) = @_;
	$value =~ s/'/\\'/g;
	return "'$value'";
}

sub chartdirector_render
{
	my ($self) = @_;

	my $c = new XYChart(500, 300, 0xccccff, 0x000000, 1);
	$c->setBackground($c->linearGradientColor(0, 0, 0, $c->getHeight() / 2, 0xccccff, 0xffffff), 0x888888);
	$c->setRoundedFrame();
	$c->setDropShadow();
	$c->addTitle($self->{'title'}, "arialbd.ttf", 15)->setBackground(0xccccff, 0x000000, perlchartdir::glassEffect());

	my $x = 20;
	my $y = 40;
	my $col = 2;
	$col = 3 if $self->{add_images};
	my $row = 12;

	#my $table = $c->addTable($x, $y, 7, $col, $row);
	my $table = $c->addTable($x, $y, $perlchartdir::TopLeft, $col, $row);

	my $cellStyle = $table->getStyle();
	$cellStyle->setMargin2(5, 5, 4, 3);
	$cellStyle->setFontSize(10);

	#set the first row to use Arial Bold font, with a light grey (eeeeee) background.
	my $firstRowStyle = $table->getRowStyle(0);
	$firstRowStyle->setFontStyle("arialbd.ttf");
	$firstRowStyle->setBackground(0xeeeeee, $perlchartdir::LineColor);

	# set the column widths
	if ($self->{add_images})
	{
		my $firstColStyle = $table->getColStyle(0);
		$firstColStyle->setWidth(60);
		my $secColStyle = $table->getColStyle(1);
		$secColStyle->setWidth(310);
		my $thrdColStyle = $table->getColStyle(2);
		$thrdColStyle->setWidth(90);
	}
	else
	{
		my $firstColStyle = $table->getColStyle(0);
		$firstColStyle->setWidth(370);
		my $secColStyle = $table->getColStyle(1);
		$secColStyle->setWidth(90);
	}

	for (my $i=$col; $i >=0; $i--)
	{
		$table->setText($i, 0, $self->{col_labels}->[$i]);
		#$table->setText(2,0,"Downloads");
		#$table->setText(1,0,"Country");
		#$table->setText(0,0,"Flag");
	}
	my $row = 1;
	foreach (@{$self->{'data_series'}})
	{
		if ($row < 11)
		{
			if ($self->{add_images})
			{
				$table->setText(0, $row, $_->{image});
				$table->setText(1, $row, $_->{citation});
				$table->setText(2, $row, $_->{data});
			}
			else
			{
				$table->setText(0, $row, $_->{citation});
				$table->setText(1, $row, $_->{data});
			}
		}
		$row++
	}

        my $conf = $self->{params}->get('conf');
        my $path = $conf->get_path('graphs_path').'/'.$self->{filename};

        $c->makeChart( $path ) or die "Error creating graph at '$path': '$!'";

	return "<div class=\"pie_graph\">
		<table><tr>
		<td>
		<img class=\"chart\" src = \"$self->{'url_relative'}\">
		</td>
		</tr>
		</table>
		</div>";

}

sub plotkit_render
{
	my ($self) = @_;
}

1;

